@@ -11,7 +11,7 @@ from jsonrpcclient import exceptions
 from jsonrpcclient import request_log, response_log
 
 
-DEFAULT_HTTP_HEADER = {
+DEFAULT_HTTP_HEADERS = {
     'Content-Type': 'application/json',
     'Accept': 'application/json'
 }
@@ -19,7 +19,7 @@ DEFAULT_HTTP_HEADER = {
 class Server:
     """This class acts as the remote server"""
 
-    def __init__(self, endpoint, headers=None, auth=None):
+    def __init__(self, endpoint, **kwargs):
         """Instantiate a remote server object.
 
         >>> server = Server('http://example.com/api', \
@@ -27,13 +27,13 @@ class Server:
                 auth=('user', 'pass'))
         """
 
-        self.endpoint = endpoint
-        self.auth = auth
+        kwargs.setdefault('headers', DEFAULT_HTTP_HEADERS)
 
-        if headers:
-            self.headers = headers
-        else:
-            self.headers = DEFAULT_HTTP_HEADER
+        self.endpoint = endpoint
+        self.headers = kwargs['headers']
+        self.requests_kwargs = kwargs
+
+        kwargs.pop('headers')
 
     def __getattr__(self, name):
         """Catch undefined methods and handle them as RPC requests.
@@ -81,7 +81,7 @@ class Server:
                 self.endpoint,
                 self.headers,
                 json=request,
-                auth=self.auth
+                **self.requests_kwargs
             )
         # Catch the requests module's InvalidSchema exception if the json is
         # invalid.
@@ -89,7 +89,7 @@ class Server:
             raise exceptions.InvalidRequest()
         # Catch all other requests exceptions, such as network issues.
         # See http://stackoverflow.com/questions/16511337/
-        except requests.exceptions.RequestException: # The base exception
+        except requests.exceptions.RequestException: # Base requests exception
             raise exceptions.ConnectionError()
 
         # Log the response, cleaning it up a bit
